@@ -50,7 +50,7 @@ use Params::Util qw{_INSTANCE};
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '2.200';
+	$VERSION = '2.202';
 }
 
 
@@ -81,7 +81,7 @@ sub new {
 	# Load, check and add the file
 	my $template = File::Slurp::read_file( $file ) or return undef;
 	$template =~ /\[%\s+tests\s+\%\]/              or return undef;
-	$template =~ /\[\%\s+plan\s+\%\]/              or return undef;
+	# $template =~ /\[\%\s+plan\s+\%\]/              or return undef;
 	$self->{template} = $template;
 
 	$self;
@@ -145,11 +145,11 @@ See the main L<SUPPORT|Test::Inline/SUPPORT> section.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 - 2005 Phase N Austalia. All rights reserved.
+Copyright 2004 - 2007 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
